==> moodle-1.5-mysql.tgz: moodle/lang/sk/assignment.php <==
<?PHP // $Id$ 
      // assignment.php - created with Moodle 1.6 development (2005053000)


$string['allowresubmit'] = 'Povoli optovn odovzdanie zadania';
$string['assignmentdetails'] = 'Podrobnosti zadania';
$string['assignmentmail'] = '$a->teacher poslal komentr na Vami vypracovan zadanie \'$a->assignment\'

Njdete ho pripojen k Vmu vypracovanmu zadaniu:

$a->url';
$string['assignmentmailhtml'] = '$a->teacher poslal komentr na Vami vypracovan zadanie \'<i>$a->assignment</i>\'<br /><br />

Njdete ho pripojen k Vmu

<a href=\"$a->url\">vypracovanmu zadaniu</a>.';
$string['assignmentname'] = 'Nzov zadania';
$string['assignmenttype'] = 'Typ zadania';
$string['availabledate'] = 'Dostupn od';
$string['comment'] = 'Komentr';
$string['commentinline'] = 'Vloen komentr';
$string['configmaxbytes'] = 'Maximlna vekos zadania pre vetky vypracovan zadania na strnke (s ohadom na obmedzenia kurzu a ostatn miestne nastavenia)';
$string['description'] = 'Popis';
$string['duedate'] = 'Dtum, do ktorho treba zasla vypracovan zadanie';
$string['duedateno'] = 'Bez uzvierky zasielania vypracovanch zadan';
$string['early'] = '$a vas';
$string['editmysubmission'] = 'Upravi moje vypracovan zadanie';
$string['emailteachermail'] = '	
$a->username aktualizoval zaslanie vypracovanho zadania pre \'$a->assignment\'

Je dostupn tu:

$a->url';
$string['emailteachermailhtml'] = '$a->username aktualizoval zaslanie vypracovanho zadania pre <i>\'$a->assignment\'</i><br /><br />. Je to <a href=\"$a->url\">dostupn na www strnke</a>.';
$string['emailteachers'] = 'Posiela uiteom oznmenia o zaslan vypracovanho zadania tudentmi na emailov adresu';
$string['emptysubmission'] = 'Ete ste ni neposlali';
$string['existingfiledeleted'] = 'Existujci sbor bol vymazan: $a';
$string['failedupdatefeedback'] = 'Nepodarilo sa aktualizova komentr na vypracovan zadanie pre uvatea $a';
$string['feedback'] = 'Komentr';
$string['feedbackfromteacher'] = 'Komentr od $a';
$string['feedbackupdated'] = 'Komentr na vypracovan zadania bol aktualizovan pre $a ud';
$string['helpoffline'] = '	<p>Tto vobu je vhodn poui, ak vypracovvate zadanie mimo prostredia Moodle. Me to by kdekovek na webe alebo systmom tvrou-v-tvr.</p><p>tudenti si mu prezrie popis zadania, ale nemu prenies iadne sbory ani okovek in. Systm znmkovania funguje normlne a tudenti bud oboznmen so svojimi znmkami.</p>';
$string['helponline'] = '<p>Tento typ zadania vyaduje od tudentov, aby si upravili text vyuitm tandardnch nstrojov na to urench. Uitelia ich mu znmkova hne (online) a mu k tomu dokonca pridva rzne komentre, alebo zmeny.</p>
 <p>(Ak mte sksenosti so starmi verziami Moodle, tento Typ zadania m rovnak monosti a funkcie ako mal modul Psomn prca.)</p>';
$string['helpuploadsingle'] = '<p>Tento typ zadania povouje kadmu astnkovi prenies si jeden sbor akhokovek typu.</p> <p>Toto me by dokument textovho editoru Word, obrzok, zozipovan wwww strnka alebo okovek in, o nariadite tudentom, aby Vm odoslali.</p>';
$string['late'] = '$a neskoro';
$string['maximumgrade'] = 'Maximlna znmka';
$string['maximumsize'] = 'Maximlna vekos';
$string['modulename'] = 'Zadanie';
$string['modulenameplural'] = 'Zadania';
$string['newsubmissions'] = 'Zadania odovzdan';
$string['noassignments'] = 'Ete nie s iadne zadania';
$string['noattempts'] = 'Ete nikto sa nepoksil vypracova toto zadanie';
$string['notgradedyet'] = 'Ete neoznmkovan';
$string['notsubmittedyet'] = 'Ete neodovzdan';
$string['overwritewarning'] = 'Upozornenie: Optovn odovzdanie zadania NAHRAD Vau predchdzajcu verziu (pvodn zadanie bude odstrnen)';
$string['preventlate'] = 'Predchdza neskorm odovzdvaniam zadan ';
$string['saveallfeedback'] = 'Uloi vetky moje komentre';
$string['submission'] = 'Odovzdan zadanie';
$string['submissionfeedback'] = 'Komentr na odovzdan lohu';
$string['submissions'] = 'Odovzdan zadania';
$string['submissionsaved'] = 'Vae zmeny boli uloen';
$string['submitassignment'] = 'Odovzdajte Vae zadanie prostrednctvom tohto formulra';
$string['submitted'] = 'Zadanie bolo odovzdan';
$string['typeoffline'] = 'innos offline ';
$string['typeonline'] = 'Online text';
$string['typeuploadsingle'] = 'Prenies jeden sbor';
$string['uploadbadname'] = 'Tento nzov sboru obsahoval zvltne znaky a nemohol by prenesen';
$string['uploadedfiles'] = 'prenesen sbory';
$string['uploaderror'] = 'Poas ukladania sboru na server sa vyskytla chyba';
$string['uploadfailnoupdate'] = 'Sbor bol prenesen v poriadku, ale systm nedokzal aktualizova Vae odovzdan zadanie!';
$string['uploadfiletoobig'] = 'Prepte, ale tento sbor je privek (limit je $a bytov)';
$string['uploadnofilefound'] = 'Sbor nebol njden. Urite ste vybrali sbor na prenesenie?';
$string['uploadnotregistered'] = '\'$a\' bol prenesen v poriadku, ale nebol njden zznam o odovzdan zadania!';
$string['uploadsuccess'] = '\'$a\' bol prenesen spene';
$string['viewfeedback'] = 'Zobrazi hodnotenie odovzdanho zadania a komentre k nemu';
$string['viewsubmissions'] = 'Zobrazi $a odovzdanch zadan';
$string['yoursubmission'] = 'Vae zadanie';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/sk/assignment.php <==
<?PHP // $Id$ 
      // assignment.php - created with Moodle 1.6 development (2005053000)


$string['allowresubmit'] = 'Povoli optovn odovzdanie zadania';
$string['assignmentdetails'] = 'Podrobnosti zadania';
$string['assignmentmail'] = '$a->teacher poslal komentr na Vami vypracovan zadanie \'$a->assignment\'

Njdete ho pripojen k Vmu vypracovanmu zadaniu:

$a->url';
$string['assignmentmailhtml'] = '$a->teacher poslal komentr na Vami vypracovan zadanie \'<i>$a->assignment</i>\'<br /><br />

Njdete ho pripojen k Vmu

<a href=\"$a->url\">vypracovanmu zadaniu</a>.';
$string['assignmentname'] = 'Nzov zadania';
$string['assignmenttype'] = 'Typ zadania';
$string['availabledate'] = 'Dostupn od';
$string['comment'] = 'Komentr';
$string['commentinline'] = 'Vloen komentr';
$string['configmaxbytes'] = 'Maximlna vekos zadania pre vetky vypracovan zadania na strnke (s ohadom na obmedzenia kurzu a ostatn miestne nastavenia)';
$string['description'] = 'Popis';
$string['duedate'] = 'Dtum, do ktorho treba zasla vypracovan zadanie';
$string['duedateno'] = 'Bez uzvierky zasielania vypracovanch zadan';
$string['early'] = '$a vas';
$string['editmysubmission'] = 'Upravi moje vypracovan zadanie';
$string['emailteachermail'] = '	
$a->username aktualizoval zaslanie vypracovanho zadania pre \'$a->assignment\'

Je dostupn tu:

$a->url';
$string['emailteachermailhtml'] = '$a->username aktualizoval zaslanie vypracovanho zadania pre <i>\'$a->assignment\'</i><br /><br />. Je to <a href=\"$a->url\">dostupn na www strnke</a>.';
$string['emailteachers'] = 'Posiela uiteom oznmenia o zaslan vypracovanho zadania tudentmi na emailov adresu';
$string['emptysubmission'] = 'Ete ste ni neposlali';
$string['existingfiledeleted'] = 'Existujci sbor bol vymazan: $a';
$string['failedupdatefeedback'] = 'Nepodarilo sa aktualizova komentr na vypracovan zadanie pre pouvatea $a';
$string['feedback'] = 'Komentr';
$string['feedbackfromteacher'] = 'Komentr od $a';
$string['feedbackupdated'] = 'Komentr na vypracovan zadania bol aktualizovan pre $a ud';
$string['helpoffline'] = '	<p>Tto vobu je vhodn poui, ak vypracovvate zadanie mimo prostredia Moodle. Me to by kdekovek na webe alebo systmom tvrou-v-tvr.</p><p>tudenti si mu prezrie popis zadania, ale nemu prenies iadne sbory ani okovek in. Systm znmkovania funguje normlne a tudenti bud oboznmen so svojimi znmkami.</p>';
$string['helponline'] = '<p>Tento typ zadania vyaduje od tudentov, aby si upravili text vyuitm tandardnch nstrojov na to urench. Uitelia ich mu znmkova hne (online) a mu k tomu dokonca pridva rzne komentre, alebo zmeny.</p>
 <p>(Ak mte sksenosti so starmi verziami Moodle, tento Typ zadania m rovnak monosti a funkcie ako mal modul Psomn prca.)</p>';
$string['helpuploadsingle'] = '<p>Tento typ zadania povouje kadmu astnkovi prenies si jeden sbor akhokovek typu.</p> <p>Toto me by dokument textovho editoru Word, obrzok, zozipovan wwww strnka alebo okovek in, o nariadite tudentom, aby Vm odoslali.</p>';
$string['late'] = '$a neskoro';
$string['maximumgrade'] = 'Maximlna znmka';
$string['maximumsize'] = 'Maximlna vekos';
$string['modulename'] = 'Zadanie';
$string['modulenameplural'] = 'Zadania';
$string['newsubmissions'] = 'Zadania odovzdan';
$string['noassignments'] = 'Ete nie s iadne zadania';
$string['noattempts'] = 'Ete nikto sa nepoksil vypracova toto zadanie';
$string['notgradedyet'] = 'Ete neoznmkovan';
$string['notsubmittedyet'] = 'Ete neodovzdan';
$string['overwritewarning'] = 'Upozornenie: Optovn odovzdanie zadania NAHRAD Vau predchdzajcu verziu (pvodn zadanie bude odstrnen)';
$string['preventlate'] = 'Predchdza neskorm odovzdvaniam zadan ';
$string['saveallfeedback'] = 'Uloi vetky moje komentre';
$string['submission'] = 'Odovzdan zadanie';
$string['submissionfeedback'] = 'Komentr na odovzdan lohu';
$string['submissions'] = 'Odovzdan zadania';
$string['submissionsaved'] = 'Vae zmeny boli uloen';
$string['submitassignment'] = 'Odovzdajte Vae zadanie prostrednctvom tohto formulra';
$string['submitted'] = 'Zadanie bolo odovzdan';
$string['typeoffline'] = 'innos offline ';
$string['typeonline'] = 'Online text';
$string['typeuploadsingle'] = 'Prenies jeden sbor';
$string['uploadbadname'] = 'Tento nzov sboru obsahoval zvltne znaky a nemohol by prenesen';
$string['uploadedfiles'] = 'prenesen sbory';
$string['uploaderror'] = 'Poas ukladania sboru na server sa vyskytla chyba';
$string['uploadfailnoupdate'] = 'Sbor bol prenesen v poriadku, ale systm nedokzal aktualizova Vae odovzdan zadanie!';
$string['uploadfiletoobig'] = 'Prepte, ale tento sbor je privek (limit je $a bytov)';
$string['uploadnofilefound'] = 'Sbor nebol njden. Urite ste vybrali sbor na prenesenie?';
$string['uploadnotregistered'] = '\'$a\' bol prenesen v poriadku, ale nebol njden zznam o odovzdan zadania!';
$string['uploadsuccess'] = '\'$a\' bol prenesen spene';
$string['viewfeedback'] = 'Zobrazi hodnotenie odovzdanho zadania a komentre k nemu';
$string['viewsubmissions'] = 'Zobrazi $a odovzdanch zadan';
$string['yoursubmission'] = 'Vae zadanie';

?>
